@@ -17,19 +17,36 @@ Draw bounding boxes over detected object
 
 from typing import Any, Dict
 from peekingduck.pipeline.nodes.node import AbstractNode
-from peekingduck.pipeline.nodes.draw.utils.drawfunctions import draw_bboxes
+from peekingduck.pipeline.nodes.draw.utils.bbox import draw_bboxes
 
 
 class Node(AbstractNode):
-    """Draw node for drawing bboxes onto image"""
+    """Draw bounding boxes on image.
 
-    def __init__(self, config: Dict[str, Any]) -> None:
-        super().__init__(config, node_path=__name__)
-        self.bbox_thickness = config["bbox_thickness"]
-        self.bbox_color = tuple(config["bbox_color"])
+    The draw bbox node uses the bboxes and, optionally, the bbox labels from the model
+    predictions to draw the bbox predictions onto the image.
+    For better understanding of the usecase, refer to the
+    `object counting usecase <use_cases/object_counting.html>`_.
+
+    Inputs:
+
+        |img|
+
+        |bboxes|
+
+        |bbox_labels|
+
+    Outputs:
+        |none|
+
+    Configs:
+        None.
+    """
+
+    def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
+        super().__init__(config, node_path=__name__, **kwargs)
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
-
         draw_bboxes(inputs["img"], inputs["bboxes"],
-                    self.bbox_color, self.bbox_thickness)  # type: ignore
+                    inputs["bbox_labels"], self.show_labels)  # type: ignore
         return {}
