@@ -20,18 +20,39 @@ from typing import Any, Dict, List
 
 import numpy as np
 from peekingduck.pipeline.nodes.node import AbstractNode
-from peekingduck.pipeline.nodes.draw.utils.drawfunctions import draw_bboxes, draw_tags
+from peekingduck.pipeline.nodes.draw.utils.bbox import draw_bboxes, draw_tags
+from peekingduck.pipeline.nodes.draw.utils.constants import TOMATO
 
 
 class Node(AbstractNode):
     """This node draws large bounding boxes over multiple object bounding boxes
-    which have been identified as belonging to large groups."""
+    which have been identified as belonging to large groups.
 
-    def __init__(self, config: Dict[str, Any]) -> None:
-        super().__init__(config, node_path=__name__)
-        self.tag = config["tag"]
-        self.bbox_thickness = config["bbox_thickness"]
-        self.bbox_color = tuple(config["bbox_color"])
+    The draw group_bbox_and_tage node uses the obj_groups and large_groups from the
+    dabble nodes to draw group bboxes and the large group message tag onto the image.
+    For better understanding, refer to
+    `group size checking usecase <use_cases/group_size_checking.html>`_.
+
+    Inputs:
+
+        |img|
+
+        |bboxes|
+
+        |obj_groups|
+
+        |large_groups|
+
+    Outputs:
+        |none|
+
+    Configs:
+        tag (:obj:`str`): **default = "LARGE GROUP!"**
+            string message printed in the case of a large group detected.
+    """
+
+    def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
+        super().__init__(config, node_path=__name__, **kwargs)
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
         """ Draws large bounding boxes over multiple object bounding boxes
@@ -50,10 +71,9 @@ class Node(AbstractNode):
         group_tags = self._get_group_tags(
             inputs["large_groups"], self.tag)
 
-        draw_bboxes(inputs["img"], group_bboxes,
-                    self.bbox_color, self.bbox_thickness)   # type: ignore
-        draw_tags(inputs["img"], group_bboxes,
-                  group_tags, self.bbox_color)  # type: ignore
+        # show labels set to False to reduce clutter on display
+        draw_bboxes(inputs["img"], group_bboxes, TOMATO, False)   # type: ignore
+        draw_tags(inputs["img"], group_bboxes, group_tags, TOMATO)  # type: ignore
 
         return {}
 
