@@ -18,18 +18,38 @@ Draws keypoints on a detected pose
 
 from typing import Any, Dict
 from peekingduck.pipeline.nodes.node import AbstractNode
-from peekingduck.pipeline.nodes.draw.utils.drawfunctions import draw_human_poses
+from peekingduck.pipeline.nodes.draw.utils.pose import draw_human_poses
 
 
 class Node(AbstractNode):
-    """Node for drawing poses onto image"""
+    """Node for drawing poses onto image
 
-    def __init__(self, config: Dict[str, Any]) -> None:
-        super().__init__(config, node_path=__name__)
-        self.keypoint_dot_color = tuple(config["keypoint_dot_color"])
-        self.keypoint_dot_radius = config["keypoint_dot_radius"]
-        self.keypoint_connect_color = tuple(config["keypoint_connect_color"])
-        self.keypoint_text_color = tuple(config["keypoint_text_color"])
+    The draw poses node uses the keypoints, keypoint_scores, and keypoint_conns
+    predictions from pose models to draw the human poses onto the image.
+    For better understanding, check out the pose models.
+
+    Inputs:
+
+        |img|
+
+        |keypoints|
+
+        |keypoint_scores|
+
+        |keypoint_conns|
+
+    Outputs:
+        |none|
+
+    Configs:
+        None.
+    """
+
+    def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
+        super().__init__(config, node_path=__name__, **kwargs)
+        self.keypoint_dot_color = tuple(self.config["keypoint_dot_color"])
+        self.keypoint_connect_color = tuple(self.config["keypoint_connect_color"])
+        self.keypoint_text_color = tuple(self.config["keypoint_text_color"])
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
         """function that draws pose details onto input image
@@ -39,10 +59,5 @@ class Node(AbstractNode):
         """
         draw_human_poses(inputs["img"],  # type: ignore
                          inputs["keypoints"],
-                         inputs["keypoint_scores"],
-                         inputs["keypoint_conns"],
-                         self.keypoint_dot_color,  # type: ignore
-                         self.keypoint_dot_radius,
-                         self.keypoint_connect_color,  # type: ignore
-                         self.keypoint_text_color)  # type: ignore
+                         inputs["keypoint_conns"])  # type: ignore
         return {}
