@@ -19,15 +19,33 @@ Displays a tag on bounding box
 from typing import Any, Dict
 
 from peekingduck.pipeline.nodes.node import AbstractNode
-from peekingduck.pipeline.nodes.draw.utils.drawfunctions import draw_tags
+from peekingduck.pipeline.nodes.draw.utils.bbox import draw_tags
+from peekingduck.pipeline.nodes.draw.utils.constants import TOMATO
 
 
 class Node(AbstractNode):
-    """Node that draws tags above bounding boxes"""
+    """Node that draws tags above bounding boxes
 
-    def __init__(self, config: Dict[str, Any]) -> None:
-        super().__init__(config, node_path=__name__)
-        self.tag_color = config["tag_color"]
+    The draw tag node uses the bboxes, obj_tags predictions from
+    dabble nodes and models to draw the tags of the bboxes onto the image.
+
+    Inputs:
+
+        |img|
+
+        |bboxes|
+
+        |obj_tags|
+
+    Outputs:
+        |none|
+
+    Configs:
+        None.
+    """
+
+    def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
+        super().__init__(config, node_path=__name__, **kwargs)
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:
         """Draws a tag above each bounding box.
@@ -39,7 +57,6 @@ class Node(AbstractNode):
             outputs (dict): Dict with keys "none".
         """
 
-        draw_tags(inputs["img"], inputs["bboxes"],
-                  inputs["obj_tags"], self.tag_color)
+        draw_tags(inputs["img"], inputs["bboxes"], inputs["obj_tags"], TOMATO)
 
         return {}
