@@ -1,31 +1,32 @@
+# Copyright 2019 The TensorFlow Authors, Pavel Yakubovskiy, Björn Barz. All Rights Reserved.
+#
+# Modifications copyright 2021 AI Singapore
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ==============================================================================
+# Contains definitions for EfficientNet model.
+#
+# [1] Mingxing Tan, Quoc V. Le
+#   EfficientNet: Rethinking Model Scaling for Convolutional Neural Networks.
+#   ICML'19, https://arxiv.org/abs/1905.11946
+#
+# Code of this model implementation is mostly written by
+# Björn Barz ([@Callidior](https://github.com/Callidior))
+
 """
-Copyright 2019 The TensorFlow Authors, Pavel Yakubovskiy, Björn Barz. All Rights Reserved.
-
-Modifications copyright 2021 AI Singapore
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-==============================================================================
-Contains definitions for EfficientNet model.
-
-[1] Mingxing Tan, Quoc V. Le
-  EfficientNet: Rethinking Model Scaling for Convolutional Neural Networks.
-  ICML'19, https://arxiv.org/abs/1905.11946
-
-Code of this model implementation is mostly written by
-Björn Barz ([@Callidior](https://github.com/Callidior))
+EfficientNet parameters and constants
 """
 
-
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
