@@ -23,12 +23,12 @@ from peekingduck.pipeline.nodes.node import AbstractNode
 class Node(AbstractNode):
     """This is a template class of how to write a node for peekingduck."""
 
-    def __init__(self, config: Dict[str, Any]) -> None:
-        super().__init__(config, node_path=__name__)
+    def __init__(self, config: Dict[str, Any] = None, **kwargs: Any) -> None:
+        super().__init__(config, node_path=__name__, **kwargs)
 
         # initialize/load any configs and models here
-        # self.config1 = config["config1"]
-        # self.logger.info("model loaded with configs: %s", configs)
+        # configs can be called by self.<config_name> e.g. self.filepath
+        # self.logger.info("model loaded with configs: %s", config)
 
     def run(self, inputs: Dict[str, Any]) -> Dict[str, Any]:  # type: ignore
         """ This node does ___.
