@@ -16,57 +16,37 @@
 Pipeline class that stores nodes and manages the data information used during inference
 """
 
-import copy
 import textwrap
 from typing import List, Dict, Any
 from peekingduck.pipeline.nodes.node import AbstractNode
 
 
+# pylint: disable=R0903
 class Pipeline:
-    """ Pipe class that stores nodes and manages the data information used during inference
+    """ Pipe class that stores nodes and manages flow of data used during inference
+
+    Args:
+        nodes (:obj: `List`): List of initiated nodes for the pipeline to run through
+
+    Returns:
+        None
+
     """
 
     def __init__(self, nodes: List[AbstractNode]) -> None:
-        """
-        Args:
-            nodes (:obj:'list' of :obj:'Node'): node stack as declared for use in
-                inference pipeline
-        """
+
         self.nodes = nodes
         self._check_pipe(nodes)
-        self._data = {}  # type: ignore
+        self.data = {}  # type: ignore
         self.terminate = False
 
-    def __del__(self) -> None:
-        for node in self.nodes:
-            del node
-
-    def execute(self) -> None:
-        """ executes all node contained within the pipeline
-        """
-        for node in self.nodes:
-            if "pipeline_end" in self._data and self._data["pipeline_end"]:  # type: ignore
-                self.terminate = True
-                if "pipeline_end" not in node.inputs:
-                    continue
-
-            if "all" in node.inputs:
-                inputs = copy.deepcopy(self._data)
-            else:
-                inputs = {key: self._data[key]
-                          for key in node.inputs if key in self._data}
-
-            outputs = node.run(inputs)
-            self._data.update(outputs)  # type: ignore
-
-
     def get_pipeline_results(self) -> Dict[str, Any]:
         """get all results data of nodes in pipeline
 
         Returns:
             Dict[Any]: Dictionary of all pipeline node results
         """
-        return self._data
+        return self.data
 
     @staticmethod
     def _check_pipe(nodes: List[AbstractNode]) -> None:
